# remirepo spec file for php-pecl-parallel
#
# Copyright (c) 2019 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:          %scl_package        php-pecl-pthreads}

%global pecl_name parallel
%global ini_name  40-%{pecl_name}.ini

Summary:        Parallel concurrency API
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        1.0.3
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        PHP
URL:            http://pecl.php.net/package/%{pecl_name}
Source0:        http://pecl.php.net/get/%%{pecl_name}-%{version}.tgz

BuildRequires:  %{?scl_prefix}php-zts-devel > 7.2
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  autoconf

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name} = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name}) = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name} = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa} = %{version}-%{release}

%if "%{?vendor}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
Obsoletes:     php72u-pecl-%{pecl_name} <= %{version}
Obsoletes:     php72w-pecl-%{pecl_name} <= %{version}
%if "%{php_version}" > "7.3"
Obsoletes:     php73-pecl-%{pecl_name}  <= %{version}
Obsoletes:     php73w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:     php74-pecl-%{pecl_name}  <= %{version}
Obsoletes:     php74w-pecl-%{pecl_name} <= %{version}
%endif
%endif

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter shared private
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
A succinct parallel concurrency API for PHP 7.

This extension is only available for PHP in ZTS mode.

Documentation: http://php.net/parallel

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{pecl_name}-%{version}

# Sanity check, really often broken
extver=$(sed -n '/define PHP_PARALLEL_VERSION/{s/.* "//;s/".*$//;p}' php_parallel.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable "%{summary}" extension module
extension=%{pecl_name}
EOF


%build
%{?dtsenable}

cd %{pecl_name}-%{version}
%{_bindir}/zts-phpize
%configure \
    --enable-parallel \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}


%install
%{?dtsenable}

make -C %{pecl_name}-%{version} install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Documentation
cd %{pecl_name}-%{version}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do sed -e 's/\r//' -i $i
   install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
cd %{pecl_name}-%{version}

: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{_bindir}/zts-php \
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
SKIP_ONLINE_TESTS=1 \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{_bindir}/zts-php -n run-tests.php --show-diff


%files
%{?_licensedir:%license %{pecl_name}-%{version}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so


%changelog
* Mon May 27 2019 Remi Collet <remi@remirepo.net> - 1.0.3-1
- update to 1.0.3

* Thu May 23 2019 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Tue May 21 2019 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Mon May 20 2019 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0 (stable)

* Wed May  8 2019 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0
- raise dependency on PHP 7.2

* Mon Mar 25 2019 Remi Collet <remi@remirepo.net> - 0.8.3-1
- update to 0.8.3 (beta)

* Thu Feb 28 2019 Remi Collet <remi@remirepo.net> - 0.8.2-1
- update to 0.8.2 (beta)

* Mon Feb 25 2019 Remi Collet <remi@remirepo.net> - 0.8.1-1
- update to 0.8.1 (beta)

* Mon Feb 18 2019 Remi Collet <remi@remirepo.net> - 0.8.0-1
- update to 0.8.0 (beta)

* Tue Feb 12 2019 Remi Collet <remi@remirepo.net> - 0.0.1-0
- initial package
- test build for upcoming version 0.0.1 (beta)
